package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````F!\```````!``````````-BA````
M````!0```$``.``+`$``&@`9``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```#,`@``````
M`,P"````````S`(````````A`````````"$``````````0`````````#``!P
M!````&^@`````````````````````````````&8````````````````````!
M``````````$````%````````````````````````````````````.)8`````
M```XE@`````````0`````````0````8```"@FP```````*"K````````H*L`
M``````"P!````````-@$`````````!`````````"````!@```+B;````````
MN*L```````"XJP```````!`"````````$`(````````(``````````0````$
M````J`(```````"H`@```````*@"````````)``````````D``````````0`
M````````!`````0````8E@```````!B6````````&)8````````@````````
M`"``````````!`````````!0Y71D!````.".````````X(X```````#@C@``
M`````.P`````````[``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``"@FP```````*"K````````H*L```````!@!````````&`$`````````0``
M```````$````%`````,```!'3E4`2>#F4]>.3[I2KS?J;DLMBAIQ#;XO;&EB
M+VQD+6QI;G5X+7)I<V-V-C0M;'`V-&0N<V\N,0`````1````1@````0````(
M````()`0`05`!,0H`@$$@(8$A(*)``()(`0(B(`00;H``H@`````1@```$D`
M``!,````30```%4```!6````6````%H```!;````7````%X```!@````80``
M`&,``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!
ML@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#FVL)0]9FK\QF&7X*AT)%U>R)
M!W#3<U"?V#-BV^T^S])L%8PES`PZEPO_8?)A?ZF<F^"G`@IK&IY0H^#[20``
M`````````````````````````````````````````P`+`!`>````````````
M``````#4`@``$0````````````````````````#5````$@``````````````
M``````````#-`0``$@````````````````````````"P`@``$@``````````
M``````````````"'````$@````````````````````````!.`0``$@``````
M``````````````````"#`@``$@````````````````````````#4`0``$@``
M``````````````````````!E`0``$@````````````````````````"5`0``
M$@````````````````````````#K````$@````````````````````````"?
M`@``$@````````````````````````"Z`@``$0``````````````````````
M``"*`@``$@````````````````````````"(`0``$@``````````````````
M```````<`0``$@`````````````````````````,`0``$@``````````````
M``````````#^````$@````````````````````````#L`0``$@``````````
M``````````````#;`0``$@````````````````````````"^`0``$@``````
M``````````````````#"`@``$@`````````````````````````!````(```
M```````````````````````"`@``$@````````````````````````!L`0``
M$@`````````````````````````=````(``````````````````````````P
M`@``$@````````````````````````"F`0``$@``````````````````````
M```W````$@````````````````````````"1`@``$@``````````````````
M``````"X`@``$0````````````````````````!4````%@``````````````
M``````````#[`0``$@`````````````````````````^`0``$@``````````
M``````````````"8`@``$@````````````````````````!G````$@``````
M``````````````````!M`@``$@````````````````````````#$````$@``
M``````````````````````!X````$@````````````````````````"-`0``
M$@````````````````````````"H````$@````````````````````````#:
M````$@````````````````````````#%`0``$@``````````````````````
M``!F`@``$@````````````````````````#F`0``$@``````````````````
M```````P`0``$@````````````````````````"?`0``$@``````````````
M``````````!0`@``$@````````````````````````!)`@``$0``````````
M``````````````#?````$@````````````````````````"V`0``$@``````
M```````````````````O`@``$@````````````````````````!7`@``(@``
M``````````````````````"3````$@`````````````````````````+`@``
M$@````````````````````````#A`0``$@````````````````````````!T
M`@``$@````````````````````````!9`0``$@``````````````````````
M```A`@``$@````````````````````````"<`P``$@``````````````````
M``````"W````$0`````````````````````````3`@``$@``````````````
M```````````E`0``$@````````````````````````!%````$@``````````
M```````````````W`@``$@````````````````````````![`@``$@``````
M``````````````````!W`0``$@````````````````````````"O`0``$@``
M``````````````````````"E`P``$@`+`!HU````````I``````````W!```
M$@`+`*(N````````R@0```````!$`@``$@`+`!`>````````B`$````````<
M`P``$@`+`!(F`````````@`````````Z`P``$@`+`&PS````````K@$`````
M``!=!```$@`+`!0F````````I@$````````=!```$``6`%"P````````````
M```````M`P``$@`+`+HG````````(@````````!0`P``$@`+`#PL````````
M3@````````"]`P``$0`,`&A-````````!`````````#Z`P``$@`+`+1*````
M````]``````````5!```$@`+`#XE````````*``````````R!```$``6`'BP
M``````````````````!+!```$@`+`.(M````````P`````````!T!```$@`+
M`(HL````````2`````````#,`P``$``5``"P``````````````````!T`P``
M$@`+`-PG````````X`````````#H`P``$`#Q_P"X``````````````````!$
M!```$``5`%"P``````````````````!J!```$0`5`$BP````````"```````
M```%!```$``5`%"P``````````````````#2`P``$@`+`)@?````````(@``
M``````#9`P``$``5``"P```````````````````I!```$@`+`%Y*````````
M5@````````#.`P``(``5``"P``````````````````"Q`P``$``6`'BP````
M``````````````"*`P``$@`+`,PM````````%@````````!>`P``$@`+`&8E
M````````K`````````"``P``$@`+`*A+````````M`$```````!\!```$@`+
M`+PH````````@`,`````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F
M;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F
M86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P
M96XV-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD
M:7(`<F5A9`!M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`<F5A9&QI;FL`
M<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?
M7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE
M`'-T<F-H<@!M96UC;7``;65M<V5T`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M
M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`<W1R;F-M<`!?7V5N=FER
M;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R
M;"YS;RXU+C0P`&QI8F,N<V\N-@!L9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O
M+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS
M7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!?7T)34U]%3D1?7P!?24]?<W1D:6Y?=7-E9`!?
M7V1A=&%?<W1A<G0`7U]$051!7T)%1TE.7U\`7U]G;&]B86Q?<&]I;G1E<B0`
M<VAA7W5P9&%T90!?7U-$051!7T)%1TE.7U\`>'-?:6YI=`!?7V)S<U]S=&%R
M=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE`'!A<E]I
M;FET7V5N=@!'3$E"0U\R+C,T`$=,24)#7S(N,S,`1TQ)0D-?,BXR-P``````
M`@`!``,``P`!``$``P`#``,``P`!``,``P`#``,``0`!``$``P`#``,``P`!
M``,``0`!``0``P`!``,``P`!``,``0`#``$``P`!``$``P`!``,``P`#``,`
M`0`#``,``P`!``,`!``#``$``P`#``,``0`#``,``0`#``$``0`%``,``P`#
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``````````$``P#V`@``$````$````"TD98&```%
M`(D$```0````LY&6!@``!`"4!```$````(>1E@8```,`GP0````````!``$`
M``,``!``````````AY&6!@```@"?!````````*"K`````````P````````"Z
M'P```````*BK`````````P````````!,(````````+"K`````````P``````
M```4(````````/BO`````````P`````````0'@````````"P`````````P``
M````````L````````!BP`````````P````````#(3@```````""P````````
M`P`````````P40```````"BP`````````P`````````X40```````#"P````
M`````P````````!`40```````#BP`````````P````````!(40```````$BP
M`````````P````````!040```````*"O`````````@````(`````````````
M`*BO`````````@````P``````````````+"O`````````@````X`````````
M`````+BO`````````@```!@``````````````,"O`````````@```!L`````
M`````````,BO````````"P```"$``````````````-"O`````````@```",`
M`````````````-BO`````````@```"4``````````````."O`````````@``
M`#(``````````````.BO`````````@```#8``````````````/"O````````
M`@```#X``````````````-BM````````!0````,``````````````."M````
M````!0````0``````````````.BM````````!0````4``````````````/"M
M````````!0````8``````````````/BM````````!0````<`````````````
M``"N````````!0````@```````````````BN````````!0````D`````````
M`````!"N````````!0````H``````````````!BN````````!0````L`````
M`````````""N````````!0````T``````````````"BN````````!0````\`
M`````````````#"N````````!0```!```````````````#BN````````!0``
M`!$``````````````$"N````````!0```!(``````````````$BN````````
M!0```!,``````````````%"N````````!0```!0``````````````%BN````
M````!0```!4``````````````&"N````````!0```!8``````````````&BN
M````````!0```!<``````````````'"N````````!0```!D`````````````
M`'BN````````!0```!H``````````````("N````````!0```!P`````````
M`````(BN````````!0```!T``````````````)"N````````!0```!X`````
M`````````)BN````````!0```!\``````````````*"N````````!0```"(`
M`````````````*BN````````!0```"0``````````````+"N````````!0``
M`"8``````````````+BN````````!0```"<``````````````,"N````````
M!0```"@``````````````,BN````````!0```"D``````````````-"N````
M````!0```"H``````````````-BN````````!0```"L``````````````."N
M````````!0```"P``````````````.BN````````!0```"T`````````````
M`/"N````````!0```"X``````````````/BN````````!0```"\`````````
M``````"O````````!0```#````````````````BO````````!0```#$`````
M`````````!"O````````!0```#,``````````````!BO````````!0```#0`
M`````````````""O````````!0```#4``````````````"BO````````!0``
M`#<``````````````#"O````````!0```#@``````````````#BO````````
M!0```#D``````````````$"O````````!0```#H``````````````$BO````
M````!0```#L``````````````%"O````````!0```#P``````````````%BO
M````````!0```#T``````````````&"O````````!0```#\`````````````
M`&BO````````!0```$```````````````'"O````````!0```$$`````````
M`````'BO````````!0```$(``````````````("O````````!0```$,`````
M`````````(BO````````!0```$0``````````````)"O````````!0```$4`
M````````````````````````EY,``#,#PT$#OH,U$P-#_9."@S434Q,`@[*"
M`&<`#@`7G@```SZ.-&<##@`3````%YX```,^#C1G`PX`$P```!>>```#/HXS
M9P,.`!,````7G@```SX.,V<##@`3````%YX```,^CC)G`PX`$P```!>>```#
M/@XR9P,.`!,````7G@```SZ.,6<##@`3````%YX```,^#C%G`PX`$P```!>>
M```#/HXP9P,.`!,````7G@```SX.,&<##@`3````%YX```,^CB]G`PX`$P``
M`!>>```#/@XO9P,.`!,````7G@```SZ.+F<##@`3````%YX```,^#BYG`PX`
M$P```!>>```#/HXM9P,.`!,````7G@```SX.+6<##@`3````%YX```,^CBQG
M`PX`$P```!>>```#/@XL9P,.`!,````7G@```SZ.*V<##@`3````%YX```,^
M#BMG`PX`$P```!>>```#/HXJ9P,.`!,````7G@```SX.*F<##@`3````%YX`
M``,^CBEG`PX`$P```!>>```#/@XI9P,.`!,````7G@```SZ.*&<##@`3````
M%YX```,^#BAG`PX`$P```!>>```#/HXG9P,.`!,````7G@```SX.)V<##@`3
M````%YX```,^CB9G`PX`$P```!>>```#/@XF9P,.`!,````7G@```SZ.)6<#
M#@`3````%YX```,^#B5G`PX`$P```!>>```#/HXD9P,.`!,````7G@```SX.
M)&<##@`3````%YX```,^CB-G`PX`$P```!>>```#/@XC9P,.`!,````7G@``
M`SZ.(F<##@`3````%YX```,^#B)G`PX`$P```!>>```#/HXA9P,.`!,````7
MG@```SX.(6<##@`3````%YX```,^CB!G`PX`$P```!>>```#/@X@9P,.`!,`
M```7G@```SZ.'V<##@`3````%YX```,^#A]G`PX`$P```!>>```#/HX>9P,.
M`!,````7G@```SX.'F<##@`3````%YX```,^CAUG`PX`$P```!>>```#/@X=
M9P,.`!,````7G@```SZ.'&<##@`3````%YX```,^#AQG`PX`$P```!>>```#
M/HX;9P,.`!,````7G@```SX.&V<##@`3````%YX```,^CAIG`PX`$P```!>>
M```#/@X:9P,.`!,````7G@```SZ.&6<##@`3````%YX```,^#AEG`PX`$P``
M`!UQANRFY*J'HNC*X$[\EY0``(.T)!@NZ#+D#`@P`&@(/LZ<8#[T@4?O\)_X
M%Y8```,VQA:RA1>5```#-249[R#P<)>7``"#M^<9@\<'`.G/EY<``(.WAQ87
ME```$P0$'Y*7F&-R28-'ITL;!4D`#@63YS<`(PWW2N_PG^["91>6```#-J8;
M\D<#N`4`JH87-P``$P>G*!<U```3!:4GF.X4Y".P!@&(YI#J!4<-*6-6]PRA
M!1N%-P`11Y!ADQ<W`+:7!2>0XZ$%XQFG_@X'"&PVER,P!P!*A@%'EP4``).%
MI5_O\/^]/<4(;),)00+O\#_=*HG.A1<U```3!27U[P``%"G-"&SO\+^W[_!_
MSB)WG&"YCP%'O>?F8$9DIF3B>4J%!FDE88*`[_"?R1>4```3!,01".PAQ>_P
MG]&7EP``@[?'!X5F,X='`!AC-I<C"P>2.;<(;._PO[YYMPAH`<7O$*!:1;?.
MA1<U```3!87F[P#@#`CH6=7EMQ%'@;\%1>_P'[OO\-_E[P`@`JJ'%Y4```,U
MI06"93``$W$!_X%&`4<*B._PW^$"D)>A``"3@6&$@H`!`!>5```3!:4(EY<`
M`).')PACB*<`EY<``(.WY_V1PX*'@H`7E0``$P6%!I>5``"3A04&B8V3US5`
M_9&^E86%F<67EP``@[>G^Y'#@H>"@)>7``"#Q\<#G>=!$0;DEY<``(.W9_R1
MQQ>5```#-47]@I?O\!_YHF"%1Q>7```C"?<`00&"@(*`<;\Y<0;\(OA:X)>7
M``"#MZ?U`[L'`&,!"PA*\$[L4NB#1P4`JHDNBBJ)$P?0`[W#8X;G`(-'&0`%
M"?W[.PDY00,T"P`AS";T5N3:A),*T`-*ALZ%(H7O\/^@LP<D`0GE@\<'`&.`
M5P.`9*$$=?"B=`)YXFE":J)JXG`BA4)T`FLA88*`LX1D08V$!0DC()H`2I3Q
MOP%);;<!1/F_`GGB:4)JV;]Q<2+Q)NT&]9>4``"#M(3J+`"<8#[E@4<JA._P
M?\$-X>)'O6819_6/8X7G`"EG8YKG`"*%B47O\+^@$S45`!&@`44J9YQ@N8\!
M1Y'GJG`*=.ID36&"@._PO\HQ<4KQ!OT7F0```SD)Y8,W"0`^Y8%'&<4B^8-'
M!0`JA(GO2G0J9X,W"0"YCP%'8YT'#.IP"GDI88*`)O7O\+_%JH1C"04,3NTF
MA>_PWY=!S8-&-0&3"34!FX8F_1N&!@"9X@/&&0!MT@-'-0$;!R?]FP8'``'K
M@\<9`)N')_V;A@<`I<_QTB*%4NGO\-^1*HI.A>_P7Y$[!:H`"27O\+^1SH<B
MAY<V``"3AB:X?5:%1:J)[_!?NBP`3H7O\-^=_5=C"/4`XD>]9A%G]8]CBN<"
M3H7O\%^83H7O\/^F)H5*:N_P?XXU]2:%[_#_FR*%[_"?E4ITJG3J:36W@\8I
M`%FW3H7O\/_OP;\B^2;U3NU2Z>_P?[E*=*IT,;<=<:+HIN3*X(;L3OQ2^%;T
M6O`7F0```SFIT@/'!0"#-PD`/N2!1Y,'T`,NA*J$8Q3W`!.$%0`BA>_P7X4J
MBDP`)H7O\)_:JHEIR>_P/X1C=44+DDH7FP```SN+SXX*`\<$`*:'DP;0`V,*
M!Q)C!M<``\<7`(4'??N%GX,Y"P`3!2H`/I76F>_P?X$CL*D`*<6#-PL``\<$
M`!.%%`#6EY1C$P;0`R.`Y@`!Z[6@`T<%``4%HX#G`"7#MH>%!N,8Q_X3!]`#
M(X#G`(4'`T<$``4$A0>CC^?^=?LB9X,W"0"YCP%'\>/F8$9DIF0&:>)Y0GJB
M>@)[)6&"@(-'!``%!(4)HX_Y_O';@T<$``4$A0FCC_G^_?/1M[:'9;=>[&+H
M%YL```,[Z\(#/`L`@S<,`*W+XH>!29AGH0?.AH4I9?^-)I.5-@"7EP``@Z<'
MRQ>7```3!X?*E>N%1RZ%',/O\`_TJHLQQ9.:.0#BA5:&[_`?C2,P>P&;AQD`
MC@>^FR.P"P#B:T)L3L+AO6*%[_`_E2,PJP"JBPG-DYHY`.F_@4?QO<%%@4E%
MMU[L8NCO\#^>XFM";!VW77&BX/UR!60F_$KX3O12\(;D5NP3!X0`%I$*EY>9
M``"#N<FV*HDNBA,&]/\L`!<U```3!263@[<)`!SC@4?O\*_VFP0%`&->D`"3
M!P0!BI<SA(=`FX?T_SZ4`T>$_RGCG>^7EP``@[?GM%*&RH62EXAC[_!O[H5G
MH0>*EYAC@[<)`+F/`4>IXX5B%I&F8`9DXG1">:)Y`GKB:F%A@H"^A"``(H4F
MAI,%\`+O\/^"5=F7EP``@[<'L*:&(H:2EXACRH7O\&_Z1;_O\!^101$BX!>4
M```#-`2N!N27=@``DX;FG+,'1`"(8Q>6```#-@:MES4``).%!8CO\!^*$I0(
M8`)DHF`7-P``$P?'O[J&@4<7%@``$P9&Y)<U``"3A86'00%O\&_QEY<``(.W
MIZB7=@``DX:FEQ>6```#-B:HDI>(8Y<U``"3A>6";_#_A%UQ^7*)9X;DHN`F
M_$KX3O03AX<!%I$*EY>9``"#N2FB@[<)`!SC@4?O\"_I(``%9BJ'!08BA9<W
M``"3AT>"ES8``).&1H*%1>_P+_^%9\$'LP3Q`"*%IH4%9N_P#^`;!`4``4EC
M3P0`&P44`._P[](JB0')(H:FA4J4[_`/XR,`!`")9^$'BI>88X.W"0"YCP%'
MF>N)8A:1IF!*A09DXG1">:)Y86&"@._P+_Z1OQ5Q_7*%9Z+IIN7*X5KQANU.
M_5+Y5O5>[6+I$X>'"!:1"I<7FP```SNKEBJ)+H07)0``$P7E>4P`@S<+`!SC
M@4?O\+^?JH23!?`"2H7O\`_E,<$7)0``$P6E>,J%[_!?OTJ%A6>3AX<(BI>8
M8X,W"P"YCP%'8Y<'$H5B%I'N8$YDKF0.:>IY2GJJ>@I[ZFM*;"UA@H`BA>_P
M;^.7)0``DX4E=>_PK[XJA$W5A6J3APH)BI>SBU=!@T<$`),)@0@3"H$`V<^1
MQ**%)H7O\"_5)<TBA>_PK\"3!_7_HI<JC),&\`)C:/0`,:@C@`<`_1=C!O0`
M`\<'`.,)U_XBA>_P#[XJC$J%[_"/O6*5!07C<U7UA44BATJ(ER<``).'YVV7
M)@``DX;F;05F3H7O\"_FTH5.A>_PK\D!Z8.GB_B]9B%G]8]C@.<$ER4``).%
M96H!1>_PS[,JA.,.!>Z#1P0`O?.9R(/'!`";AR?]&X<'`)GC`\<4`&G;!4P7
M)```$P3$9$FWA45.A>_P;[E5_<Z%%R4``!,%Y63O\+^K3H7O\`_3R;7O\*_C
M01&3!?`"(N`&Y"J$[_"OU!G!$P05`"*%`F2B8$$!;_"/T'EQA6?]<DKH!O0B
M\";L$X>'`!:1%XD```,Y"7L*EX,W"0`<XX%'0<&#1P4`JH2ES^_P3ZX3!A4`
MA6<JA&/NQP@X`*:%.H7O\.^^DP?T_ZJ7DP;P`F-H]0`1J".`!P#]%V.&IP`#
MQP<`XPG7_B``(H63!?`"[_`/S!W%8VRD!"@`[_!/R(5GH0>*EYAC@S<)`+F/
M`4>AYX5B%I&B<`)TXF1":45A@H"%9Z$'BI>88X,W"0"YCP%'G>.%8A:1HG`"
M=.)D0FD7)0``$P6%4T5A;_!OPR,`!0!EMP%%;;?O\(_3>7$B\";L2N@&])>$
M``"#M*1MG&`^Y(%'0``7B0```SFI;:*%%R4``!,%A5/O\&_V#<421X,W"0`.
M![J7F&>8XVW3F&NA!YCC;?^BA1<E```3!051[_#O\VG]%XD```,YJ6FBA1<E
M```3!850[_!O\@W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47)0``$P4%
M3N_P[^]I_1>)```#.:EEHH47)0``$P4%3>_P;^X-Q1)'@S<)``X'NI>89YCC
M;=.8:Z$'F.-M_Z*%%R4``!,%A4KO\._K:?T7B0```SFI8:*%%R4``!,%!4KO
M\&_J#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<E```3!85'[_#OYVG]
M%XD```,YJ5VBA1<E```3!85&[_!OY@W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8
MXVW_HH47)0``$P4%1._P[^-I_1>)```#.:E9HH47)0``$P6%0^_P;^(-Q1)'
M@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%%R4``!,%!4'O\._?:?T7B0```SFI
M5:*%%R4``!,%!3CO\&_>#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<E
M```3!84U[_#OVVG]%XD```,YJ5&BA1<E```3!84\[_!OV@W%$D>#-PD`#@>Z
MEYAGF.-MTYAKH0>8XVW_HH47)0``$P4%.N_P[]=I_1>)```#.:E-HH47)0``
M$P6%.>_P;]8-Q1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%%R4``!,%!3?O
M\._3:?T7B0```SFI2:*%%R4``!,%A3;O\&_2#<421X,W"0`.![J7F&>8XVW3
MF&NA!YCC;?^BA1<E```3!04T[_#OSVG]%XD```,YJ46BA1<E```3!04I[_!O
MS@W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47)0``$P6%)N_P[\MI_:*%
M%R4``!,%!3#O\._*JH49Q1<E```3!04M[_!/ZZ*%%R4``!,%I2_O\`_)JH49
MQ1<E```3!24P[_!OZ:*%%R4``!,%13#O\"_'JH4=R1<E```3!<4?[_"/YR)G
MG&"YCP%'H>,"=*)PXF1":9<E``"3A>4O%R4``!,%Y2-%86_P#^6BA1<E```3
M!>4L[_#/PJJ%8=47)0``$P7E(^_P+^-MO^_PCYL!$2+H!NP7A````S3D-4P`
M%R4``!,%Q2$<8#[D@4?O\$^_%<&#1P4``46)QY.'!_TS-?``(F<<8+F/`4>9
MY^)@0F0%88*``47UM^_PKY8=<0;L%X,```,S(S4JC@,U`P`3`X$"+O0R^#;\
M<H:ZX!>.```#/FXOON3"Z,;LFH:%18,W#@`^Y(%'&N#OX+_K$P7P#^_@/^==
M<<%RP6=*^$[T4O"&Y*+@)OQ6[%KH$X>'`!:1"I<7B@```SH**X,W"@`<XX%'
M"4:!1:J)[^"_]A,)]?\35_E#09.S!^D`PA?!DYF/,PGY0&-%"0B*A/U:'4L!
M1LJ%3H7OX/_S8P-5"4%F(0:FA4Z%[_#O@`$E8P15!V-\JP1A%3.$I`!C=I0`
MJ:!]%&-CE`0A1I>%``"3A44J(H7OX#_M;?4S!21`2I7!9Z$'BI>88X,W"@"Y
MCP%'G>_!8A:1IF`&9.)T0GFB>0)ZXFI":V%A@H#!=SZ9XQ+Y^'U5\;<7)0``
M$P6%%N_P/^T7)0``$P7%%._P?^SO\(^"01$&Y._@']'OX-_[$<$(8:)@00&"
M@#EQ)O1*\`;\%XD```,Y:1NJA$P`%R4``!,%)1.#-PD`/N2!1^_PCZ09Q2+X
M@T<%`"J$G>-"=")G@S<)`+F/`4>FA1<E```3!440K>?B<*)T`GDA86_P[\(F
MA4[L[^`_RZJ)(H7OX+_*3I4)!>_@/\LBB":'ER<``).'I_J7)@``DX8F^WU6
MA44JA._@7_,B9X,W"0"YCP%'E>.BA4)TXFGB<*)T`GD7)0``$P4%"B%A;_`O
MO2+X3NSOX'_U[^`_]9>'``"3AV<6`[B'`V5Q`[\'`8.^AP$#O@<"`[.'`H.X
M!P/*^L[VTO(&YR+C$PG!`1>*```#.NH,JHD7)@``$P9&!I<F``"3AD;O%R<`
M`!,'QP67)P``DX?'!<+\RH47)0``$P4%[@,X"@!"_@%(`OB"Y/KH]NSR\)KT
MQO@R\#;T.OR^X._PCY(1Q8-'!0`JA&.>!QRF_M;N[^!_NN_@/^5C"P44`&%C
M"`04(H7OX#^Z!@4%!>_@O[H#1P0`JH2JBAG/)H67)@``DX:F_WU6A47OX/_B
M`T<4``4$B01]\X0(%R4``!,%9?0AH(ADH00-P<J%[_"OBRJ$;=F#1P4`]=?O
M\.^4?=$BA>_@?],JA!GM!!"`8`',@T<$`&.,!PPBA>_P[Y)=[8!DH01U]"*%
M[^`?LJJ$5H7OX)^QJ9R;A$1`)H7OX-^QUHB7)P``DX?GX2*'%R@``!,(2/>7
M)@``DX9&]WU6A46JBN_@?]E6A9,%`!SOX-_*_5=C&/4`[^`_L!Q!14=CE.<,
M#`%6A>_@/\\JA!GERD>]9A%G]8]C@.<*EX<``(.WY_F#M@D`B&-6AQ<F```3
M!N;VA47OX%_2@41R=X,W"@"YCP%'8Y8'+KI@&F3V:E9YMGD6>B:%]G1988*`
M(H7OX+_%*H2A!.,#!?(UOP%$);\D&(A@&<G*A>_@__H!Q8-'!0"%XXADH01]
M]35%[^#?I*J$JHH7)```$P3$YQ,',`5QO>_@?\$JA*$$8=7OX-^A!@4%!:V]
MVNIJ2^_@_Y]C!JL$5FN9OQ>'```#-R?O@[8)``AC%R8``!,&1NA6AX5%[^"?
MQY&_[_!?S7)W@S<*`+F/`4=CD@<D(H4:9+I@5GFV>19Z66%OX#^[RD?>YA,'
M`!R3]_<?8X7G`%9KMFOUO2:%[^!_F\J%JH07)0``$P5E[._@7^^JA6,,!1`#
MM0D`[_#/RJJ+8P4%$%Z%[^#?EQL+!0"-1V/89P,3!<O_7I67)0``DX6%Z>_@
M'ZH)[9%'8P3[&)L'N__>EP/'!P"3!_`"8POW%LJ%%R4``!,%A<OOX'_I:<&#
M1P4`U<\3!P`#8XOG"I<E``"3A473%R4``!,%1<GO\(^([^`?I"J(5H<FA9<H
M``"3B.CRER<``).'9\&7)@``DX9FY7U6A47OX+^Y?5G%21<K```3"ZOP%:CO
MX)^0'$%CG3<#[^#_GP4D*HA:X**(5H=*AB:%ER<``).'1[V7)@``DX9&XH5%
M[^"_M9,%`!PFA>_@'Z?C`B7]5H7OX'^CIH47)0``$P4%N._@W_\FA>_P7[=6
M:[9K];.#NPD`W;U>A8%%[^#_MRJ),='O\)^DJHGC3@7RDP5E_P%&2H7OX%^=
M$PL!$-J%2H491N_@?ZJ91V,>]0@#)P$0MT=!0Y.'!S#C%O?P`U=+`)%GDX>'
M5.,?]^Z3A>G\`49*A>_@?YD@`DJ%HH43!H`"[^"?II,'@`)C'O4$(HB7*```
MDX@HXI<G``"3AZ>P5H>7)@``DX:&TWU6A44FA2,(`1+OX'^H+;^#N8D`XX4)
MZ$Z%[^!O_(U'X_^GYG$53I67)0``DX4%S^_@'X_C%07FSHN5M1<E```3!47.
M[_!_D]KJWN;OX%^IIO[6[MKJWN;OX)^H.7$B^!>$```#-(3%2O!.[`;\)O12
MZ+,'1`"$8Y,)00`7B0```SE)P8/'!`O.A1<E```3!>6J`S<)`#KD`4>CB/0*
M[^`?RAG%`T<%`),'$`-C"_<2[_#/S[,'1`"$8R:%C48%1I<E``"3A87*[^"/
M^*J$'<$<:3,'1``(8XQC%R8``!,&9LGOX._WG&B,8]Q%$Y>7`F-%!Q"S!T0`
MB&.-1@5&ER4``).%I<?OX*_TJH07B@``$PK*PPW!SH47)0``$P6%G._@_\&<
M:"J&C&-IP;,'1`"(8^_@[_*S!T0`A&,%1I<E``"3A27$)H7OX(_FJH47)@``
M$P:FQ":%[^"/\!*4'&#.A1<E```3!>66HX@'"N_@'[TC.*H`*H0YQ9,%`!PB
MA>_@'X,;!Q4`A4=C\.<"Q4=C#?4`@S>*`*J&(H:,8Q<E```3!:7"[^"_AR)G
M@S<)`+F/`4>IZ^)P0G2B=`)YXFE":B%A@H`#-8H`[_"?G",XJ@`JA%WQ%R4`
M`!,%I;SOX#^$@T<5`..*!^S9M8,WB@`NA8QC[^!?\3V_LP=$`(AC[^`/_\6]
M[^"_C7EQ(O`F[`;T%X0```,TY*>JA$P`%R4``!,%I9,<8#[D@4?OX#^Q`<V#
M1P4`B<L3!P`#8X;G`('$@\<$`)GK(F<<8+F/`4>A[Z)P`G3B9$5A@H`FA4KH
M[_#/II,%\`(JB>_@;_D9P1,)%0!*A>_@K_411I<E``"3A<6=[^#/T1G!0FEU
MOR)G'&"YCP%'D>L"=$)IHG`FA>)D16%OX'^Y2NCOX'^#$P$!U)>#``"#L^.=
M-`#!;B,\$2HC.($J(S21*B,P(2LC/#$IDPB%`Y,/A0>#MP,`(S3Q*(%'-HB3
MC@[P-P__``.V"`"A"$$(DU4&`A,7A@$3DX4!DQ*&`)-7A@("%Q->A@`35(8#
M`9,"$[/RX@&S]]<!$U,#`C-G5P`S?MX!H@7!CS-GQP$;5H8!L_7E`;/G9P!1
MC\V/(SCH_B,\^/[CD?C[1G_F?@IG8FX"<Z)X0GCB=89O$X0&(!&@LH^P8IQB
MNH*A!K&/L\?G`;/'QP$3EQ<`_8-=CP(7`9.X_AJ.=H]&@Y:.PH@NB/Z%XQC4
M_!!A#&D#.(4!(FZ#.(4``S,%`I-7M@$3%U8`-X^"6A,/GYE=CWJ>L\8%`0(7
M&IZ3WB@``9.3E^@!L_86`;/GUP%RE[/&!@$VEQ.>!P+"9A->#@*3'P<",\?%
M`9/?#P)QC_J6D]*_`9.>7P`MC\*6L^Y>`!-4)@#B8C:7DQ;F`<&.=I>3'@<"
MM8^3W@X",X?B`;/W]P$3U+X!+I>3DEX`L\?'`;/B@@"ZEP)T$Y?O`9/?+P`S
M9_<!EI>"%Y.2!@*YCH&3LP_D`9/2`@*S]M8!?IX3U+<!DY]7`+/&5@#REC/N
MCP#REJ)_$Y[N`9/>+@`S;MX!$Q0'`H(6,T?'`8&2`9"SCN\!?8^6GI.?5@"3
MTK8!(8]VE[/N7P!VE\)_DY[G`8F#L^[^`+-'W@&3$@X"`A<!DY/2`@(SCN\!
M]8\BGI,?5P`35+<!L\=7`/*7,^Z/`/*7XG\3GN8!B8(S;MX`L\;.`1.4#@*"
M%X&3`9"SCN\!^8Z6GI.?5P"3TK<!H8[VEK/N7P#VEH9ODQ[G`0F#L^[N`#-'
MW@&3$@X"@A:!DI/2`@(SCN\!?8\BGI.?5@`3U+8!,T=7`'*7,^Z/`'*7IF\3
MGN<!B8,S;OX`L\?.`1.4#@("%P&3`9"SCN\!]8^6GI,?5P"34K<!H8_VE[/N
M7P#VE\9ODY[F`8F"L^[>`+-&W@&3$@X"@A>!DY/2`@(SCN\!^8XBGI.?5P`3
MU+<!L\96`/*6,^Z/`/*6YF\3'N<!"8,S;NX`,\?.`1.4#@*"%H&2`9"SCN\!
M?8^6GI.?5@"3TK8!(8]VE[/N7P!VEX9_DY[G`8F#L^[^`+-'W@&3$@X"`A<!
MDY/2`@(SCN\!]8\BGI,?5P`35+<!L\=7`/*7,^Z/`/*7IG\3GN8!B8(S;MX`
ML\;.`1.4#@*"%X&3`9"SCN\!^8Z6GI.?5P"3TK<!H8[VEK/N7P#VEL9_DQ[G
M`0F#L^[N`#-'W@&3$@X"@A:!DI/2`@(SCN\!?8\BGI.?5@`3U+8!,T=7`'*7
M,^Z/`'*7YG\3GN<!B8,S;OX`L\?.`1.4#@("%P&3`9"SCN\!]8^6GI,?5P"3
M4K<!H8_VE[/N7P#VEXIODY[F`8F"L^[>`+-&W@&3$@X"@A>!DY/2`@(SCN\!
M^8XBGI.?5P`3U+<!L\96`/*6,^Z/`/*6JF\3'N<!"8,S;NX`,\?.`1.4#@*"
M%H&2`9"SCN\!?8^6GI.?5@"3TK8!(8]VE[/N7P!VEY.?YP'*;HF#L^__`+-'
M_@&3$@X"`A<!DY/2`@(SCNX!]8\BGI,>5P`35+<!L\=7`/*7,^Z.`/*7ZF03
MWB8`DY[F`8(7@9.S[LX!$]FW`;/&WP$3E`\"$YY7``&0LX_D`3-N+@'YCI:?
MH8X"'A->#@+^EO*6"GD37B<`DY(&`I,?YP&3T@("L^_/`3/'_@&3E`X"$YY2
M`+,.Z0$3W[(!@9`S;NX!?8^BGB6/`AX37@X"=I<3E.<!B8-REUV,L\>/`*I^
M$QD'`A-9"0*UC[?VV6Z3AA:Z$U^Y`1,>60`S;NX!MIZ"%Z:>@9,"'O:7$UX.
M`CZ>$Y_B`9/2(@`S;U\`RG>3%`X"@9"S3N0!D]*T`;/.[@""'Q.75`"3WP\"
M,V=7`+:7@AZ3W@X"_I<"%_:7`9,^EY,>Z0$362D`L^XN`>IWDQ('`I/2`@*S
M3]\!$]FR`;//SP$"%!.>4@`!D#-N+@&VEX(?D]\/`J*7`A[^EQ->#@(^GI.?
MY`&)@+/OGP".9Q,4#@(!D+/$_@$36;0!N8P"'Q,75``37P\",V<G`;:7@A2!
MD/J7`A>FEP&3/I<3G^(!D]<B`#-O_P"3$@<"KF>3T@("L\3O`1/9L@&SQ,0!
M@AX3GE(`D]X.`C-N+@&VEX(4@9#VEP(>II<37@X"/IZ3'N0!DU<D`+/N_@`3
M%`X"SF<!D+-$WP$36;0!N8R"'Q,75`"3WP\",V<G`;:7@A2!D/Z7`A>FEP&3
M/I>3G^(!D]<B`+/O_P"3$@<"[F>3T@("L\3^`1/9L@&SQ,0!`A\3GE(`$U\/
M`C-N+@&VEX(4@9#ZEP(>II<37@X"/IX3'^0!DU<D`#-O_P`3%`X"CG<!D+/$
M[P$36;0!N8R"'A,75`"3W@X",V<G`;:7@A2!D/:7`A>FEP&3/I>3GN(!D]<B
M`+/N_@"3$@<"KG>3T@("LT3?`1/9L@&SQ,0!@A\3GE(`D]\/`C-N+@&VEX(4
M@9#^EP(>II<37@X"/IZ3'^0!DU<D`+/O_P`3%`X"SG<!D+/$_@$36;0!N8P"
M'Q,75``37P\",V<G`;:7@A2!D/J7`A>FEP&3/I<3G^(!D]<B`#-O_P"3$@<"
M[G>3T@("L\3O`1/9L@&SQ,0!@AX3GE(`D]X.`C-N+@&VEX(4@9#VEP(>II<3
M7@X"/IZ3'N0!DU<D`+/N_@`3%`X"DF<!D+-$WP$36;0!N8R"'Q,75`"3WP\"
M,V<G`;:7@A2!D/Z7`A>FEP&3/I>3G^(!D]<B`+/O_P"3$@<"LF>3T@("L\3^
M`1/9L@&SQ,0!`A\3GE(`$U\/`C-N+@&VEX(4@9#ZEP(>II<37@X"/IX3'^0!
MDU<D`#-O_P`3%`X"TF<!D+/$[P$36;0!N8R"'A,75`"3W@X",V<G`;:7@A2!
MD/:7`A>FEP&3/I>3GN(!D](B`+/N7@#R9Y,4!P*!D+-"WP$3V;0!L\+"`8(?
M$YY4`)/?#P(S;BX!MI>"$I/2`@+^EP(>EI<37@X"/IZ3$N0!DU<D`+/B\@`3
M%`X"DG<!D+//7@`36;0!L\_O``(?$Q=4`!-?#P(S9R<!MI>"'Y/?#P+ZEP(7
M_I<!DSZ7DY_D`8F`L^^?`+)W$QD'`A-9"0(SS_(!DU2Y`3-/SP&"'A,>60"3
MW@X",VZ>`+:7`A\37P\"]I<"'OJ7$UX.`K..QP$3'^0!"8`S;X\`TG>3E`X"
M@9`SSN\!$]2T`3-.[@""$A.75`"3T@("08^VEP(>$UX.`I:7`A<!DQ,4Z0'R
MEQ-9*0`S9"0!,X[G`')WLT>/`+/'UP&"'Y,>#@*3W@X"D]\/`C:7@A<3V;X!
M@9-^EY.?7@`^EY.2Y`&SYR\!B8"SXI(`/I>69[-/5`"3%`\",\[/`1,?!P(3
M7P\"@9"VEP(>DU^_`1->#@*FEY,67P"SYO8!$Y?N`?*7D]XN`#-GUP&VE[9N
MM_;&(Y,?!P(3G@<"DY<F`).'Q\V3WP\"L^;B``(4$UX.`K/T\@$!D+Z>L_;F
M`:*>Q8X3%%X`DU2^`?:6LVZ4`/:65F23%.\!DUXO`+/NU`$3GP(",V?7`9.2
M!@*3T@("LP;T`#-WQP$S]/X!$U\/`C:?D]2R`4&/$Y12`),6[@%ZEQ->+@`S
M;Y0`L^;&`7J7=F\3E`8"`9`S[MX``A<!D[/TC@`^GS-^7@!^GS-NG@"3'U<`
MDU2W`7J>,^^?`'J>EG03F>(!$]\B`#-OZ0&3'PX"L^;F`8(>D]\/`K-RCP`S
MCO0`D]X.`OF.=IZSYE8`$]F_`9.27P"3%.<!DUXG`#.'Q@&SYM0!,^XB`;9^
M<I>3D@8"D]("`C-NWP`"%P&3LW1?`+Z>,W[^`:*>,VZ>`!,45P"35+<!=IZS
M;I0`5G23E.\!D]\O`+/O]`%VGI,>#@*SYO8!`A^3W@X",P[T`!-?#P(S]%\`
M^8YZGL&.$]F^`1.47@"3%.<!$U\G`#.'Q@&SYN0!,VXD`79_<I<3E`8"`9`S
M[M\``A<!D[/TCP`^GS-^W@$6GS-NG@"3$E<`DU2W`7J>,^^2`)IBDY3N`9/>
M+@"S[M0!>IX3'PX"L^;6`8(?$U\/`C..\@"3WP\"L_*.`/F.?IZSYE8`$UF_
M`9,27P"3%.<!DU\G`#.'Q@&SYO0!,^XB`;IO<I>3D@8"D]("`C/NW@`"%P&3
ML_1>`+Z?,W[N`:*?,VZ>`!,45P"35+<!?IZS;Y0`6F23%.\!$U\O`#/OY`%^
MGI,?#@*SYN8!@AZ3WP\",P[T`)/>#@(S=%\`^8YVGL&.$]F_`1.47P"3%.<!
MDUXG`#.'Q@&SYM0!,VXD`?IN<I<3E`8"`9`S;M\``A<!D[-TCP"^GC-^_@&6
MGC-NG@"3$E<`DU2W`7:>L^Z2`)IRDY3O`9/?+P"S[_0!=IZ3'@X"L^;V`0(?
MD]X.`C..\@`37P\"L_*/`/F.>IZSYE8`$]F^`9.27@"3%.<!$U\G`#.'Q@&S
MYN0!,^XB`3I_<I>3D@8"D]("`C/NWP`"%P&3L_1?`#Z?,W[>`2*?,VZ>`!,4
M5P"35+<!>IXS;Y0`6G23E.X!D]XN`+/NU`%ZGA,?#@*SYM8!@A\37P\",P[T
M`)/?#P(S]%X`^8Y^GL&.$UF_`1,47P"3%.<!DU\G`#.'Q@&SYO0!,VXD`?I_
M<I<3E`8"`9`S[MX``A<!D[/TC@"^GS-^[@&6GS-NG@"3$E<`DU2W`7Z>L^^2
M`)YBDQ3O`1-?+P`S[^0!?IZ3'PX"L^;F`8(>D]\/`C..\@"3W@X"LW*/`/F.
M=IZ3U+\!DYY?`+/F5@"3$N<!"8,SY^(`\I8S[IX`OF[REI,2!P*3T@(",V[O
M`((6@9*S=%\`OIXS?OX!HIXS;IX`$Y16`)/4M@%VGK-NE`!VGEYDDY3O`9/?
M+P"3'@X",^[T`3-GQP$"'Y/>#@*S#_0`=8\S=%X`$U\/`GZ?08^3GUX`$]2^
M`7J7,^^/`/YD>I<3G^8!B8*S9M\``A<!DY.?!@*3WP\",V_>`!-9MP&^E!,4
M5P"FDC-D)`&S=/X!,W_?`3-OGP`"%`&0%I^>="*?DQ(/`I/2`@(3E.X!D]XN
M`#-DU`&^E).>4@"3U[(!P8ZS[OX``AZS]^8`$UX.`I.6#@*S?O0!)IZSY]<!
M\I>!DKZ6DQ3G`0F#V8P3F08"OGZWMY@R$UD)`C-'E`"*!Y.'9QTS1^<!$QY9
M`!-?N0$S;NX!OIX"%_Z>`9,"'A->#@)VE[,.QP$3G^(!D](B`#-O7P"3F0X"
M7GZ3V0D",\?D`9/?N0$UCP(4DY99``&0L^;V`3Z>`A<BG@&3@A:!DG*7,P[7
M`),?Z0$362D`L^\O`9,2#@)^=Y/2`@*S1O\!$]2R`;/.U@&"%).64@"!D,&.
M/I>"'I/>#@(FEX(6=I>!DKJ6DY[I`9/9*0"S[CX!$Y0&`@,W`2`!D+/$WP$3
M6;0!L\3$`0(?$QY4`!-?#P(S;BX!/I>"%(&0>I<"'B:7$UX.`CJ>$Y_B`1/7
M(@`S;^\`DQ(.`@,W@2"3T@("L\3N`1/9L@&UC((?DY92`)/?#P*SYB8!/I>"
M%(&0?I>"%B:7@9*ZEI,?Y`$35R0`L^_O`!.4!@(#-P$A`9"S1/\!$UFT`;/$
MQ`&"'A,>5`"3W@X",VXN`3Z7@A2!D':7`AXFEQ->#@(ZGI.>X@$3UR(`L^[N
M`),2#@(#-X$AD]("`K/$WP$3V;(!M8P"'Y.64@`37P\"L^8F`3Z7@A2!D'J7
M@A8FEX&2NI83'^0!$U<D`#-O[P`3E`8"`S<!(@&0L\3N`1-9M`&SQ,0!@A\3
M'E0`D]\/`C-N+@$^EX(4@9!^EP(>)I<37@X".IZ3G^(!$]<B`+/O[P"3$@X"
M`S>!(I/2`@*S1/\!$]FR`;6,@AZ3EE(`D]X.`K/F)@$^EX(4@9!VEX(6)I>!
MDKJ6DQ[D`1-7)`"S[NX`$Y0&`@,W`2,!D+/$WP$36;0!L\3$`0(?$QY4`!-?
M#P(S;BX!/I>"%(&0>I<"'B:7$UX.`CJ>$Y_B`1/7(@`S;^\`DQ(.`@,W@2.3
MT@("L\3N`1/9L@&UC((?DY92`)/?#P*SYB8!/I>"%(&0?I>"%B:7@9*ZEI,?
MY`$35R0`L^_O`!.4!@(#-P$D`9"S1/\!$UFT`;/$Q`&"'A,>5`"3W@X",VXN
M`3Z7@A2!D':7`AXFEQ->#@(ZGI.>X@$3UR(`L^[N`),2#@(#-X$DD]("`K/$
MWP$3V;(!M8P"'Y.64@`37P\"L^8F`3Z7@A2!D'J7@A8FEX&2NI83'^0!$U<D
M`#-O[P`3E`8"`S<!)0&0L\3N`1-9M`&SQ,0!@A\3'E0`D]\/`C-N+@$^EX(4
M@9!^EP(>)I<37@X".IZ3G^(!$]<B`+/O[P"3$@X"`S>!)9/2`@*S1/\!$]FR
M`;6,@AZ3EE(`D]X.`K/F)@$^EX(4@9!VEX(6)I>!DKJ6DQ[D`1-7)`"S[NX`
M$Y0&`@,W`28!D+/$WP$36;0!L\3$`0(?$QY4`!-?#P(S;BX!/I>"%(&0>I<"
M'B:7$UX.`CJ>$Y_B`1/7(@`S;^\`DQ(.`@,W@2:3T@("L\3N`1/9L@&UC((?
MDY92`)/?#P*SYB8!/I>"%(&0?I>"%B:7@9*ZEI,?Y`$35R0`L^_O`!.4!@(#
M-P$G`9"S1/\!$UFT`;/$Q`&"'A,>5`"3W@X",VXN`3Z7@A2!D':7`AXFEY.>
MX@$37@X"D](B`+/N7@`ZG@,W@2>SPM\!L\;2``(?$U\/`I,2#@(^EX(6D]("
M`H&2>I>3E%(`$]FR`3:7$Q_D`8,V`2@)@#-OCP"SY"0!,\3N`2:7MI>"'P(7
M,T[$`0&3LI>3WP\"`AZ35K<!$Q97`!->#@+^EU6.\I>3EN(!D](B`+*7L^96
M`#,&%P%VDS.'M@!"GX(7@9.3%@8"DQ4#`A,6#P("%X&2@9$!D@&3'.$4Y0SQ
M$.V#-H$H@[<#`+6/@488Z9'O@S"!*P,T`2N#-($J`SD!*H,Y@2D3`0$L@H#O
MT&^Y01$3!0`(!N3OT*^)%T@```,XZ$:W=EU,-W?I888&MR5%9S=6,A`&!Y.&
MYL^3A14P$P9F1Q,'!Q\4Z2,T!0(C.`4"(RP%!@SA(S0%`1#M&/&B8$$!@H!=
M<2;\2OA2\%;LAN2BX$[T&'63%S8`,HFZEQ!Y@A>!DS.WYP"JA)-6V0$H73J6
M,X?&`)STF/BNBA.*A`,M[9,'\`-CVB<%FUEI`%KH&XOY_U[DF@F3&PL"D]L+
M`M:95H2BA1,&``12A>_03X\3!`0$)H7OX)^IXQ4T_SL+8$$;&VL`F@L;"0G\
MDXH*!#L)*P'>FD)KHFO6A5*%2H;OT`^,(ZPD!Z9@!F3B=$)YHGD">N)J86&"
M@),'``2)GSZ$8TGY`IL)!``3BH0#3H92E=:%[]#/B+Q<$P<`!*&?O-SCD^?\
M)H4["8E`SIKOX!^B@;]*A,&_.7$B^";T3NQ2Z%K@!OQ*\%;D`[F%`H/6A0(#
MUP4#DU<Y`!.+A0.3]_<#D]F&`!-:AP";EH8`&Q>'`#,&^P`NA+/IV0"3!0#X
M,VKJ`(,Z!`.%)R,`M@#"&4(:$P:``ZJ$D]D)`S,%^P`36@H#8U7V$!,'``2[
M!_=`$4=C_^<0"4=C\^<08YX'#B*%[^#?F%J%$P:``X%%[]`ODI-7B0$3UXH!
M$UD)`9/:"@$C&40'(QLT!Z,(5`<C"O0&HPHD!R*%(PCD!N_@/Y4<8"*%X8,C
M@/0`'&#!@Z.`]``<8*&#(X'T`!Q@HX'T`!QDX8,C@O0`'&3!@Z."]``<9*&#
M(X/T`!QDHX/T`!QHX8,CA/0`'&C!@Z.$]``<:*&#(X7T`!QHHX7T`!QLX8,C
MAO0`'&S!@Z.&]``<;*&#(X?T`!QLHX?T`!QPX8,CB/0`''#!@Z.(]``<<*&#
M(XGT`!QPHXGT`$)TXG"B=`)YXFE":J)J`FLA86_`?_<=GH%%[]#O@S&_(P`%
M`!&W(P`%`*,`!0#Y%SJ5XXL'[NVW(P`%`*,`!0`C`04`HP$%`/$7.I4)1^/K
MY^S1OY=F``"#MD8J;\#?Y`$``@``````)7,O)7,````O<')O8R]S96QF+V5X
M90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z
M.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C+R5I+R5S```````N````````
M`%!!4E]414U0``````````!005)?4%)/1TY!344`````.@`````````O````
M`````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`
M`````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$````
M``!005)?0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10``
M``````!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)
M4@````````!005)?5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'
M3$]"04Q?0TQ%04X``````````#$`````````;'-E96L@9F%I;&5D`````')E
M860@9F%I;&5D``````!,1%],24)205)97U!!5$@`4UE35$5-```O=&UP````
M`%5315(`````55-%4DY!344``````````"4P,G@`````<&%R+0`````E<R5S
M)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`````
M+G!A<@````!S:&]R="!R96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T
M96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````8`````````'!E
M<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,P``
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```````````M90```````"TM````````5$U01$E2
M``!414U01$E2`%1%35``````5$U0``````!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%
M1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T
M7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T
M,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A
M<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@
M*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]
M("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@
M3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE
M("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D
M8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM
M>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U
M<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N
M("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-
M;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F
M:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B([
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*
M+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M
M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M
M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R
M9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA
M;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T
M87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(
M+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R
M;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A
M<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I
M8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@
M/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?
M34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO
M=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@
M;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H
M(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@
M(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL
M87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N
M9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O
M9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@
M<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T
M7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5
M;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*
M8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-
M;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL
M93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U
M9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF
M;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@
M*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD
M(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA
M<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@
M("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F
M:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N
M86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC
M*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I
M('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*
M?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S
M:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@
M<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD[
M"B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=
M.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z
M.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E
M871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&
M2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E
M<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A
M9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO
M861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L
M92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY
M($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE
M("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`
M24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S
M.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J
M96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@
M/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I
M;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@
M/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\
M.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A
M73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B
M*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H
M(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F
M*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E
M;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O
M;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@
M=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D[
M"GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N
M?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F
M:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E
M:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE
M7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S
M970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D
M;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S
M.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E
M<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@
M>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S
M=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB
M(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50
M871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ
M4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A
M=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q
M=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG
M<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E
M;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.
M?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY
M("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*
M+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM
M>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C
M:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?
M<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B
M=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C
M:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S
M=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0[
M"GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L
M("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I
M"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M
M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE
M9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI
M;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T
M7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N
M9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]
M("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A
M;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD
M<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@
M+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R
M;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O
M.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%
M*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)5
M1R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)]
M(&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*`'!E<FQX<VDN8P``````````0T%#2$4``(FKS>\``````1L#.^P````<
M````,(___Q`&``"XD/__!`$``&Z1__\8`0``$)+__WP!``!JDO__J`$``(23
M__\(`@``.)7__V@"```$EO__J`(``%Z6___,`@``AI;__^`"```RE___&`,`
M`#27__\L`P``VIC__W@#``#\F/__F`,``-R9___<`P``7)W__PP$``"JG?__
M,`0``/*=__](!```[)[__XP$```"G___J`0``,*?___\!```C*3__Y`%```Z
MIO__R`4``-ZF__](!@``?KO__WP&``#4N___G`8``,B\___@!@``?+[__R`'
M````````$``````````#>E(``7P!`1L,`@`0````&````*R/__\B``````<!
M`&`````L````3I#__Z(`````0@Y`3H$"B`26$%*2"),*E`QFB0:5#F;)0M)"
MTT+40M5"P43(0M9"#@!"#D"!`H@$B0:2"),*E`R5#I804,G51-+3U$22"),*
ME`Q"TD+30M0````H````D````(R0__]:`````$(.L`%&B`2)!H$"`D8*P4+(
M0LE"#@!""P```%P```"\````NI#__QH!````0@[``422"($"6(@$1LA0P4+2
M0@X`0@[``8$"B`22"$*)!DR3"@)"E`P"5M14"LA"R4+30@M&E`Q(R,G3U$B(
M!(D&DPJ4#$33U$+(0LD``%P````<`0``=)'__[0!````0@Y@4(@$B0:2"($"
MDPJ4#)4.EA`"U`K!0LA"R4+20M-"U$+50M9"#@!""VZ7$I@4`EP*UT+81`M4
MU]A$EQ*8%$;7V$27$I@41M="V````#P```!\`0``R)+__\P`````0@Y01(@$
M5`[0((D&D@B3"I0,@0*5#@)R"@Y00L%"R$+)0M)"TT+40M5"#@!""P`@````
MO`$``%23__]:`````$(.$$*(!$J!`FC(0L%>#@`````0````X`$``(J3__\H
M`````````#0```#T`0``GI/__ZP`````0@Y05`[00($"B`2)!I((DPH"@@H.
M4$+!1,A"R4+20M-"#@!""P``$````"P"```2E/__`@````````!(````0`(`
M``"4__^F`0```$(.X`%>#N`AB`2)!I((EA"!`I,*E`R5#I<2F!0"7`H.X`%"
MP4+(0LE"TD+30M1"U4+60M="V$(.`$(+'````(P"``!:E?__(@````!"#A!(
MB`2!`E#(0L%"#@!`````K`(``%R5___@`````$(.,%(.L""2"($"B`2)!@*&
M"@XP0L%"R$+)0M)"#@!""U8*#C!"P4+(0LE"TDH.`$0+`"P```#P`@``^)7_
M_X`#````0@XP2(@$B0:2"($"`S8#"LA"P4+)0M)2#@!$"P```"`````@`P``
M2)G__TX`````0@X@1(@$@0)Z"L%"R$(.`$(+`!0```!$`P``<IG__T@`````
M0@Y@0H$2`$````!<`P``HIG___H`````0@Y06@[0@`22"),*E`R!`H@$B0:5
M#I80`J(*#E!"P4+(0LE"TD+30M1"U4+60@X`0@L`&````*`#``!8FO__%@``
M``!"#A!"@0).P4(.`%````"\`P``4IK__\``````0@Y`1HD&D@B!`FB(!$;(
M6,%"R4+20@X`1`Y`@0*(!(D&D@A$DPH"0LA"TT+!0LE"TDH.`$0.0($"B0:2
M"$2(!),*`)`````0!```OIK__\H$````3@Z0`UZ2"),*E`R!`H@$`FR)!I4.
M`S@!"L%"R$+50M)"TT+41,E"#@!""P)<EA!,UF+)U5;(0L%"TD+30M1"#@!$
M#I`#@0*(!(D&D@B3"I0,E0Z6$$R7$D;60M="EA"7$@,L`0K60M=""P/@`-;7
M1)80EQ)$R=76UTB)!I4.EA"7$@`T````I`0``/2>__^N`0```$(.0$*(!%*2
M"),*@0*)!I0,`T8!"L%"R$+)0M)"TT+40@X`0@L``$0```#<!```:J#__Z0`
M````0@XP1H@$B0:!`@)""L%"R$+)0@X`0@M$D@AL"M)""TS(0M)"P43)0@X`
M1`XP@0*(!(D&0I((`#0````D!0``&(G__X@!````0@Y@3($"B0:(!)((DPH#
M#`$*P4+(0LE"TT320@X`0@L`````````,````%P%``".H/__H!0```!$#L`%
M8($"B`2)!I((DPH#8A0*P43(1,E$TD331`X`0@L``!P```"0!0``^K3__U8`
M````0@X01H$"`DK!0@X`````0````+`%```PM?__]`````!"#E!4B0:2")0,
ME0Z!`H@$DPIVEA!&EQ("0M9"UU`*P4+(0LE"TD+30M1"U4(.`$(+```\````
M]`4``."U__^T`0```$(.0%"(!(D&DPJ4#)80@0*2")4.`U`!"LA"P4+)0M)"
MTT+40M5"UD(.`$0+````$````#0&``!4M___#```````````````!````!``
M```!````1TY5```````$````#P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````0``````
M``#F`@````````$`````````]@(````````!```````````#````````(```
M``````"@JP```````"$`````````"``````````9`````````*BK````````
M&P`````````(`````````!H`````````L*L````````<``````````@`````
M````]?[_;P````#P`@````````4`````````0`T````````&`````````.`#
M````````"@````````"J!`````````L`````````&``````````5````````
M`````````````P````````#(K0````````(`````````0`4````````4````
M``````<`````````%P`````````H%0````````<`````````&!,````````(
M`````````%`'````````"0`````````8`````````!X`````````"```````
M``#[__]O``````$```@`````_O__;P````"X$@```````/___V\``````@``
M``````#P__]O`````.H1````````^?__;P`````+````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````__________\``````````'`:
M````````<!H```````!P&@```````'`:````````<!H```````!P&@``````
M`'`:````````<!H```````!P&@```````'`:````````<!H```````!P&@``
M`````'`:````````<!H```````!P&@```````'`:````````<!H```````!P
M&@```````'`:````````<!H```````!P&@```````'`:````````<!H`````
M``!P&@```````'`:````````<!H```````!P&@```````'`:````````<!H`
M``````!P&@```````'`:````````<!H```````!P&@```````'`:````````
M<!H```````!P&@```````'`:````````<!H```````!P&@```````'`:````
M````<!H```````!P&@```````'`:````````<!H```````!P&@```````'`:
M````````<!H```````!P&@```````'`:````````<!H```````!P&@``````
M`'`:````````<!H```````!P&@```````'`:````````<!H```````"XJP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H1&5B:6%N(#$T+C(N,"TQ-BD@,30N,BXP`$%E````<FES8W8``5L`
M```$$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC<W(R
M<#!?>FEF96YC96DR<#!?>FUM=6PQ<#!?>F%A;6\Q<#!?>F%L<G-C,7`P```N
M<VAS=')T86(`+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YN;W1E+D%"22UT86<`+G!R96EN:71?87)R87D`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT`"YR:7-C=BYA='1R:6)U=&5S````````````````````````
M````````````````````````````````````````````````````````````
M````````"P````<````"`````````*@"````````J`(````````D````````
M````````````!````````````````````!X````!`````@````````#,`@``
M`````,P"````````(0````````````````````$````````````````````F
M````]O__;P(`````````\`(```````#P`@```````.P`````````!```````
M```(````````````````````,`````L````"`````````.`#````````X`,`
M``````!@"0````````4````"````"``````````8`````````#@````#````
M`@````````!`#0```````$`-````````J@0```````````````````$`````
M``````````````!`````____;P(`````````ZA$```````#J$0```````,@`
M````````!``````````"``````````(`````````30```/[__V\"````````
M`+@2````````N!(```````!@``````````4````"````"```````````````
M`````%P````$`````@`````````8$P```````!@3````````$`(````````$
M``````````@`````````&`````````!F````!````$(`````````*!4`````
M```H%0```````$`%````````!````!0````(`````````!@`````````:P``
M``$````&`````````'`:````````<!H```````"@`P``````````````````
M$``````````0`````````'`````!````!@`````````0'@```````!`>````
M````6"\```````````````````0```````````````````!V`````0````(`
M````````:$T```````!H30```````'A!```````````````````(````````
M````````````?@````$````"`````````.".````````X(X```````#L````
M````````````````!````````````````````(P````!`````@````````#0
MCP```````-"/````````2`8```````````````````@`````````````````
M``"6````!P````(`````````&)8````````8E@```````"``````````````
M```````$````````````````````I````!`````#`````````*"K````````
MH)L````````(`````````````````````0`````````(`````````+,````.
M`````P````````"HJP```````*B;````````"`````````````````````@`
M````````"`````````"_````#P````,`````````L*L```````"PFP``````
M``@````````````````````(``````````@`````````RP````8````#````
M`````+BK````````N)L````````0`@````````4`````````"``````````0
M`````````-0````!`````P````````#(K0```````,B=````````.`(`````
M``````````````@`````````"`````````#9`````0````,``````````+``
M````````H````````%`````````````````````(````````````````````
MWP````@````#`````````%"P````````4*`````````H````````````````
M````"````````````````````.0````!````,````````````````````%"@
M````````'P````````````````````$``````````0````````#M`````P``
M<`````````````````````!OH````````&8````````````````````!````
M`````````````````0````,`````````````````````````U:````````#_
?`````````````````````0``````````````````````
